@@ -5,7 +5,7 @@ use Carp;
 use Tie::Hash;
 use vars qw($VERSION);
 
-$VERSION = do { my @r = (q$Revision: 0.02 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.03 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 =head1 NAME
 
@@ -15,8 +15,8 @@ Tie::Hash::MultiKey - multiple keys per value
 
   use Tie::Hash::MultiKey;
 
-  $accessor = tie %hash, qw(Tie::Hash::MultiValue);
-  $accessor = tied %hash;
+  $thm = tie %hash, qw(Tie::Hash::MultiValue);
+  $thm = tied %hash;
 
   untie %hash;
 
@@ -48,7 +48,7 @@ Tie::Hash::MultiKey - multiple keys per value
 
   All of the above methods can be accessed as:
 
-  i.e.	$accessor->consolidate;
+  i.e.	$thm->consolidate;
 
 =head1 DESCRIPTION
 
@@ -223,15 +223,15 @@ sub SCALAR {
 
 =over 4
 
-=item * $acc = tie %hash,'Tie::Hash::MultiValue';
+=item * $thm = tie %hash,'Tie::Hash::MultiValue';
 
 Ties a %hash to this package for enhanced capability and returns a method
 pointer.
 
   my %hash;
-  my $accessor = tie %hash,'Tie::Hash::MultiValue';
+  my $thm = tie %hash,'Tie::Hash::MultiValue';
 
-=item * $acc = tied %hash;
+=item * $thm = tied %hash;
 
 Returns a method pointer for this package.
 
